@@ -3,7 +3,7 @@ from os.path import expanduser
 
 from hvac.exceptions import InvalidRequest
 
-from lib.vault import Vault
+from gevault.lib.vault import Vault
 
 MOUNT_POINT = 'ssh-client-signer'
 SIGNING_ROLE = "vault-signing-role"
