@@ -6,8 +6,8 @@ import requests
 
 from requests.exceptions import ReadTimeout
 
-from lib.vault import Vault
-from lib.admin import MOUNT_POINT, SIGNING_ROLE
+from gevault.lib.vault import Vault
+from gevault.lib.admin import MOUNT_POINT, SIGNING_ROLE
 
 DEFAULT_VAULT_VARIABLE = "VAULT_TOKEN"
 
